****************
* This do file creates the tables in "Do Television and Radio Destroy Social Capital? Evidence from Indonesian Villages"
* using data from the SUSENAS data
* July 2009
* Benjamin A. Olken
* It is to be used with Stata v. 9.2 or later
*****************

version 9.2

local villagecontrols = 	"mean_adulted_w00 log_adu*p_w90 log_ham*s_w05 pop_agric_w90 sch*s_w90 num_mo*_w90 num_mu*_w90 ot*es_w90 sp*s_w90 arts_w90 soc_w90 youth_w90 eth_frag_w00 rel_frag_w00 pov_rate_w05 coastal_w90 elevation city_dist_w05 city_t*e_w05 c_cit*th_km asp*4*"  
local hhcontrols = "age gender years_educ lnexpcap"

clear
set mem 600m


use susdata,clear

qui tab kabidwave, g(kabiddummy)
drop kabiddummy1



******
* Table 10: test first stage power in SUSENAS sample
******
preserve
bys id2002: keep if _n == 1
for var sumwavedum*: keep if X > 0 & X != .
keep if wave == 2003
areg tvchannels eloss floss `villagecontrols', absorb(kabid) cluster(id1990)
testparm eloss
local fval = r(F)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table10_susenas, 3aster coefastr se replace title("`depVar'") adds("Mean dep. var",r(mean),"F stat",`fval') ctitle("1991-2003 sample")

restore


******************
* Table 11: panel analysis in SUSENAS
******************


* Regressions 
foreach depVar of var org soyouth soreligious sowomen  soburial  {
		
		* Panel 1991-2003
		preserve
		for var sumwavedum*: keep if X > 0 & X != .
		areg `depVar' tvchannels  `hhcontrols' kabiddummy* , absorb(kecnum) cluster(kecnum) 
		local depvar = e(depvar)
		qui summ `depvar' if e(sample) 
		outreg tvchannels `hhcontrols' using table11_sus_`depVar', 3aster coefastr se replace title("`depVar'") adds("Mean dep. var",r(mean)) ctitle("OLS-Panel")
		
		
		
	
		* Panel with instrument	
		xtivreg2 `depVar' (tvchannels = elosspanel) flosspanel `hhcontrols' kabiddummy* , fe i(kecnum) cluster(kecnum) ffirst
		matrix temp = e(first)
		scalar tempF = temp[3,1]
		local tempFLocal = tempF
		local depvar = e(depvar)
		qui summ `depvar' if e(sample) 
		outreg tvchannels flosspanel `hhcontrols' using table11_sus_`depVar', 3aster coefastr se append adds("Mean dep. var",r(mean),"First stage F",`tempFLocal') ctitle("IV-panel")
		restore
		
	}	
	


