****************
* This do file creates the tables in "Do Television and Radio Destroy Social Capital? Evidence from Indonesian Villages"
* using data from the java survey
* July 2009
* Benjamin A. Olken
* It is to be used with Stata v. 9.2 or later
*****************

version 9.2
clear
set mem 1g
set matsize 5000
capture log close
log using 080312tv, t replace


local villagecontrols = "elevation city_dist_w90 zmintimekab c_citypath_km ocean aspect4* log_ad*p_w90 pop_agric_w90 schools_w90 num_mos*_w90 num_mus*s_w90 ot*ites_w90 sports_w90 arts_w90 soc_w90 youth_w90 lnznumdusun zmeanad*tion czethf*g czrelf*g zpercentpoorpra"
local villagecontrolsnogeog = "log_adultpop_w90 lnznumdusun zmeanadulteducation schools_w90 num_mos*_w90 num_mus*s_w90 ot*ites_w90 sports_w90 arts_w90 soc_w90 youth_w90 elevation czethfrag czrelfrag zpercentpoorpra " 
local villagecontrolssocap = "num_mosques_w90 num_mushollas_w90 otherreligioussites_w90 sports_w90 arts_w90 soc_w90 youth_w90"
local villagecontrolselspline = "el? city_dist_w90 zmintimekab c_citypath_km ocean aspect4* log_ad*p_w90 pop_agric_w90 schools_w90 num_mos*_w90 num_mus*s_w90 ot*ites_w90 sports_w90 arts_w90 soc_w90 youth_w90 lnznumdusun zmeanad*tion czethf*g czrelf*g zpercentpoorpra"



set seed 1000


use javadata,clear
for var zsocdesanumgroupsALL zsocdesapcnumgroups* zsocdesapcactualintensityALL: g lnX = ln(X)

preserve

* make village level dataset
bys desaid: keep if _n == 1


/*prepare to drop outliers*/
qui areg numchannelskec `villagecontrols', absorb(kabnum) cluster(kecnum)
g tempsample = e(sample)

bys kabnum: egen tempnumchannelsmean = mean(numchannelskec)
g numchannelskecdemeaned = numchannelskec - tempnumchannelsmean 

egen temprank = rank(numchannelskecdemeaned) if tempsample == 1
egen tempcount = count(numchannelskecdemeaned) if tempsample  == 1
g numchannelskecdemeanedpctile = temprank / tempcount

summ temprank
local chanmin = r(min)
local chanmax = r(max) 



g str40 varname = ""
g outinfo = .
local numvar = 1
bys desaid: g tempnum = _n


************************
* Table 2 -- summary stats
************************

* village level variables
foreach X of var numchannelskec numchannelskecdemeaned zsocdesanumgroupsALL zsocdesapcnumgroupsALL {
	
	local numstd = `numvar' + 1
	qui summ `X' if tempnum == 1
	replace outinfo = r(mean) in `numvar'
	replace outinfo = -1 * r(sd) in `numstd'
	replace varname = "`X'" in `numvar'
	local numvar = `numvar' + 2
}



* hh level variables
foreach X of var zsocdesapcactualintensityALL totalminutesperday tvminutesperday radiominutesperday ztv zradio {
	
	local numstd = `numvar' + 1
	qui summ `X' 
	replace outinfo = r(mean) in `numvar'
	replace outinfo = -1 * r(sd) in `numstd'
	replace varname = "`X'" in `numvar'
	local numvar = `numvar' + 2
}

local numvar = `numvar' - 1
outsheet varname outinfo using table2.out in 1/`numvar', replace




************************
* Table 3
* Determinants of # of TV channels
************************


areg numchannelskec `villagecontrols', absorb(kabnum) cluster(kecnum)
testparm `villagecontrolssocap'
local FSTATSOCAP = r(p)
testparm `villagecontrols' 
local FSTATALL = r(p)
testparm `villagecontrolsnogeog'
local FSTAT = r(p)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table3, 3aster coefastr se adds("P-val socap,",`FSTATSOCAP',"P-value no geog",`FSTAT',"P-value all",`FSTATALL',"Mean dep. var",r(mean)) replace title("Table 2: Determinants of number of channels")



areg numchannelskec `villagecontrols' if temprank != `chanmin' & temprank != `chanmax', absorb(kabnum) cluster(kecnum)
testparm `villagecontrolssocap'
local FSTATSOCAP = r(p)
testparm `villagecontrols' 
local FSTATALL = r(p)
testparm `villagecontrolsnogeog'
local FSTAT = r(p)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table3, 3aster coefastr se adds("P-val socap,",`FSTATSOCAP',"P-value no geog",`FSTAT',"P-value all",`FSTATALL',"Mean dep. var",r(mean)) append


areg lnzsocdesanumgroupsALL `villagecontrols' if temprank != `chanmin' & temprank != `chanmax', absorb(kabnum) cluster(kecnum)
testparm `villagecontrolssocap'
local FSTATSOCAP = r(p)
testparm `villagecontrols' 
local FSTATALL = r(p)
testparm `villagecontrolsnogeog'
local FSTAT = r(p)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table3, 3aster coefastr se adds("P-val socap,",`FSTATSOCAP',"P-value no geog",`FSTAT',"P-value all",`FSTATALL',"Mean dep. var",r(mean)) append





tempfile tempranks
g sample1 = (temprank != `chanmin' & temprank != `chanmax')
g sample2 = (numchannelskecdemeanedpctile > 0.025 & numchannelskecdemeanedpctile < 0.975)
sort desaid
keep sample1 sample2 desaid
save `tempranks',replace


restore
sort desaid
capture drop _merge
merge desaid using `tempranks'

*********************************
* Analysis at household level
*********************************

tab kabnum if numchannelskec != ., g(kabdummy1wave)
g lnact = ln(zactivitiesnumber)
g lntimes = ln(zactivitiestimes)
for var zfemale zlhhexpcapnotv zrespedyears zage: g X_tv = X * numchannelskecnotyou

g zsocapminutesperdaydesa = zsocdesapcactualintensityALL * 120 / 90
g zsocapminutesperdayindividual = zactivitiestimes * 120 / 90
bys desaid: egen meanminutes = mean(totalminutesperday)



************
* Table 4 - media watching and ownership
************

* Droppping outlier subdistricts (main specification in paper)
areg totalminutesperday numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg tvminutesperday numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg radiominutesperday numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztv numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4, 3aster coefastr se adds("Mean dep. var",r(mean)) append



* Full sample
areg totalminutesperday numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4fs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("table4")

areg tvminutesperday numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg radiominutesperday numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztv numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table4fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append



******************
* Table 5
* Participation in groups
* Household regressions (cols 3 and 4)
************************



* Dropping outliers districts (main specificaiton in paper)
areg zactivitiesnumber numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hh, 3aster coefastr se adds("Mean dep. var",r(mean)) replace ctitle("All-OLS")

areg zactivitiestimes numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hh, 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("All-OLS")


* Full sample
areg zactivitiesnumber numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hhfs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace ctitle("All-OLS")

areg zactivitiestimes numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hhfs, 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("All-OLS")

**** Robustness versions for Appendix Table 1 (cols 3-4)
* No village controls
areg zactivitiesnumber numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage  using table5hhnocontrols, 3aster coefastr se adds("Mean dep. var",r(mean)) replace ctitle("All-OLS")

areg zactivitiestimes numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage  using table5hhnocontrols, 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("All-OLS")


* Elevation spline
areg zactivitiesnumber numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrolselspline' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrolselspline' using table5hhspline, 3aster coefastr se adds("Mean dep. var",r(mean)) replace ctitle("All-OLS")

areg zactivitiestimes numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrolselspline' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrolselspline' using table5hhspline, 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("All-OLS")

* Poisson

poisson zactivitiesnumber  numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' kabdummy1wave* if sample1 == 1, cluster(kecnum) 
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hhpoisson, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("`yVar'") ctitle("All-Poisson")

poisson zactivitiestimes  numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' kabdummy1wave* if sample1 == 1, cluster(kecnum) 
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hhpoisson, 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("All-Poisson")


** Village version of channels
areg zactivitiesnumber numchannelsdesanotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelsdesanotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hhvillagetv, 3aster coefastr se adds("Mean dep. var",r(mean)) replace ctitle("All-OLS")

areg zactivitiestimes numchannelsdesanotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg numchannelsdesanotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5hhvillagetv, 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("All-OLS")



* IV version of Table 5 shown in Appendix Table 2 
preserve
bys desaid: keep if _n == 1
	xi: ivreg2 lnzsocdesanumgroupsALL (meanminutes = numchannelskec) `villagecontrols' i.kabid if sample1 == 1, cluster(kecnum) ffirst 
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg meanminutes `villagecontrols' using table5ivregs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("IV regressions") bd(4)

	xi: ivreg2 lnzsocdesapcactualintensityALL (meanminutes = numchannelskec) `villagecontrols'  i.kabid if sample1 == 1, cluster(kecnum) ffirst 	
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg meanminutes `villagecontrols' using table5ivregs, 3aster coefastr se adds("Mean dep. var",r(mean)) append  bd(4)

	
restore
	xi: ivreg2 zactivitiesnumber (totalminutesperday = numchannelskecnotyou) zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' i.kabid if sample1 == 1, cluster(kecnum) ffirst 
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg totalminutesperday zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5ivregs, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(4)

	xi: ivreg2 zactivitiestimes (totalminutesperday = numchannelskecnotyou) zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' i.kabid if sample1 == 1, cluster(kecnum) ffirst 	
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg totalminutesperday zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' using table5ivregs, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(4)

	
	
* Robustness table: Interactions of TV channels with HH characteristics for Appendix Table 4
	
	areg zactivitiesnumber numchannelskecnotyou zfemale_tv zlhhexpcapnotv_tv zrespedyears_tv zage_tv zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage zfemale_tv zlhhexpcapnotv_tv zrespedyears_tv zage_tv `villagecontrols' using table5hhinteractions, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("interactions") 

	areg zactivitiestimes numchannelskecnotyou zfemale_tv zlhhexpcapnotv_tv zrespedyears_tv zage_tv zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage zfemale_tv zlhhexpcapnotv_tv zrespedyears_tv zage_tv  `villagecontrols' using table5hhinteractions, 3aster coefastr se adds("Mean dep. var",r(mean)) append 




tab zactivitiesnumber
tab zactivitiestimes





g anytvminutesdummy = (tvminutesperday > 0) if tvminutesperday != .


tempfile tempdatawithranks
save `tempdatawithranks'

***************
* Table 5 results for village-level data (cols 1-2)
****************
preserve
*Make village level
bys desaid: keep if _n == 1

* Dropping outlier subdistricts (main specification in paper)
areg lnzsocdesanumgroupsALL numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg lnzsocdesapcactualintensityALL numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5, 3aster coefastr se adds("Mean dep. var",r(mean)) append

* Robustness versions for Appendix Table 1
* Full sample
areg lnzsocdesanumgroupsALL numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5fs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg lnzsocdesapcactualintensityALL numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append


* Poisson version
poisson zsocdesanumgroupsALL numchannelskec `villagecontrols' kabdummy1wave* if sample1 == 1, cluster(kecnum) 
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5poisson, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

poisson zsocdesapcactualintensityALL numchannelskec `villagecontrols' kabdummy1wave* if sample1 == 1, cluster(kecnum) 
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5poisson, 3aster coefastr se adds("Mean dep. var",r(mean)) append

* No village controls
areg lnzsocdesanumgroupsALL numchannelskec  if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5nocontrols, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg lnzsocdesapcactualintensityALL numchannelskec  if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5nocontrols, 3aster coefastr se adds("Mean dep. var",r(mean)) append

* Elevation spline
areg lnzsocdesanumgroupsALL numchannelskec `villagecontrolselspline' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5elspline, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg lnzsocdesapcactualintensityALL numchannelskec `villagecontrolselspline' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5elspline, 3aster coefastr se adds("Mean dep. var",r(mean)) append

* Village tv variable
areg lnzsocdesanumgroupsALL numchannelsdesa `villagecontrolselspline' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5villagetv, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg lnzsocdesapcactualintensityALL numchannelsdesa `villagecontrolselspline' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table5villagetv, 3aster coefastr se adds("Mean dep. var",r(mean)) append




*******************************
* Table 6: village-level results on types of social groups
********************************

for any community womenkids ent othgrp: g zsocdesanumgroupsXALL = 0 \ g zsocdesapcaintensityXALL = 0 
for any gotong neighb school : replace zsocdesanumgroupscommunityALL = zsocdesanumgroupscommunityALL + zsocdesanumgroupsXALL  \ replace zsocdesapcaintensitycommunityALL = zsocdesapcaintensitycommunityALL + zsocdesapcaintensityXALL 
for any women health water : replace zsocdesanumgroupswomenkidsALL = zsocdesanumgroupswomenkidsALL + zsocdesanumgroupsXALL  \ replace zsocdesapcaintensitywomenkidsALL = zsocdesapcaintensitywomenkidsALL + zsocdesapcaintensityXALL 
for any scouts arts sports : replace zsocdesanumgroupsentALL = zsocdesanumgroupsentALL + zsocdesanumgroupsXALL  \ replace zsocdesapcaintensityentALL = zsocdesapcaintensityentALL + zsocdesapcaintensityXALL 
for any work politics savings other: replace zsocdesanumgroupsothgrpALL = zsocdesanumgroupsothgrpALL + zsocdesanumgroupsXALL  \ replace zsocdesapcaintensityothgrpALL = zsocdesapcaintensityothgrpALL + zsocdesapcaintensityXALL 
for any religion nonrel community womenkids ent othgrp iarisan : g zsocdesapcnumgroupsXALL = zsocdesanumgroupsXALL / (zadultpop * 1000)
for any religion nonrel community womenkids ent othgrp iarisan : g lnzsocdesanumgroupsXALL = ln(zsocdesanumgroupsXALL)
for any religion nonrel community womenkids ent othgrp iarisan : g lnzsocdesaintXALL = ln(zsocdesapcaintensityXALL)


* Dropping outlier subdistricts (main specification in paper)
areg lnzsocdesanumgroupsnonrelALL  numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg lnzsocdesaintnonrelALL numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesanumgroupsreligionALL  numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesaintreligionALL numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesanumgroupsiarisanALL  numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesaintiarisanALL numchannelskec `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6, 3aster coefastr se adds("Mean dep. var",r(mean)) append


* Full sample results
areg lnzsocdesanumgroupsnonrelALL  numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6fs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Table 4")

areg lnzsocdesaintnonrelALL numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesanumgroupsreligionALL  numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesaintreligionALL numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesanumgroupsiarisanALL  numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg lnzsocdesaintiarisanALL numchannelskec `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table6fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append


	
**********************
* Table 8 -- village development meetings
**********************

use javameetingsurvey,clear

* Main sample in paper 
xi: areg lnanyone numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if sample1 == 1 & lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Village meetings")

xi: areg lninsider numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if sample1 == 1 & lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg lnperson numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if sample1 == 1 & lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg lntalk numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if sample1 == 1 & lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8, 3aster coefastr se adds("Mean dep. var",r(mean)) append


xi: areg numprobs numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if sample1 == 1 & lm08 >= 5 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8, 3aster coefastr se adds("Mean dep. var",r(mean)) append


xi: areg anypeny numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if sample1 == 1 & lm08 >= 5 & lm08 <= 7, cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg anysevere numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if sample1 == 1 & lm08 >= 5 & lm08 <= 7, cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8, 3aster coefastr se adds("Mean dep. var",r(mean)) append

* Robustness using full sample
xi: areg lnanyone numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if  lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8fs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Village meetings")

xi: areg lninsider numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if  lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg lnperson numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if  lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg lntalk numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if  lm08 >= 4 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg numprobs numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if  lm08 >= 5 & lm08 <= 7, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg anypeny numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if  lm08 >= 5 & lm08 <= 7, cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

xi: areg anysevere numchannelskec `villagecontrols' i.lm08*i.treatment i.lm08*i.audit if  lm08 >= 5 & lm08 <= 7, cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table8fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append




restore



use javaroadsurvey, clear

**********
* Table 9: Corruption outcomes
**********


*main sample in paper
xi: areg lndiffeall4 numchannelskec `villagecontrols' audit und fpm if sample1 == 1, cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9, 3aster coefastr se adds("Mean dep. var",r(mean)) replace

xi: areg lndiffeall4mainancil numchannelskec `villagecontrols' audit und fpm if sample1 == 1 , cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(3)

xi: areg lndiffpall4 numchannelskec `villagecontrols' audit und fpm if sample1 == 1 , cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(3)

xi: areg lndiffqtall4 numchannelskec `villagecontrols' audit und fpm if sample1 == 1 , cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(3)


*robustness on full sample
xi: areg lndiffeall4 numchannelskec `villagecontrols' audit und fpm , cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9fs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace

xi: areg lndiffeall4mainancil numchannelskec `villagecontrols' audit und fpm , cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(3)

xi: areg lndiffpall4 numchannelskec `villagecontrols' audit und fpm , cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(3)

xi: areg lndiffqtall4 numchannelskec `villagecontrols' audit und fpm , cluster(kecnum) absorb(kabnum)	
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table9fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append bd(3)



**********
* Table 7: Trust regressions
**********
use `tempdatawithranks',clear
* Main specification
areg ztrustA numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title ("Trust") 

areg ztrustB numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustC numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustD numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustE numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustF numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustG numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7, 3aster coefastr se adds("Mean dep. var",r(mean)) append

*robustness full sample
areg ztrustA numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7fs, 3aster coefastr se adds("Mean dep. var",r(mean)) replace title ("Trust") 

areg ztrustB numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustC numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustD numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustE numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustF numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append

areg ztrustG numchannelskecnotyou zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' , cluster(kecnum) absorb(kabnum)
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg using table7fs, 3aster coefastr se adds("Mean dep. var",r(mean)) append






********************************
* Appendix Table 3: Examine visits to home
*******************************
g temp = 0
for var zvisit*: replace temp = temp + X
ren temp zvisit`X'
for var zvisit*: g lnX = ln(X)

foreach X of var zvisit* {
	
	areg `X' numchannelskec zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum)  absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg using tablevisit`X', 3aster coefastr se adds("Mean dep. var",r(mean)) replace title("Visits") ctitle("All")

	areg ln`X' numchannelskec zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1, cluster(kecnum)  absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg using tablevisit`X', 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("All")


	areg `X' numchannelskec zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1 & ztv == 1, cluster(kecnum)  absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg using tablevisit`X', 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("With TV")
	
	areg ln`X' numchannelskec zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1 & ztv == 1, cluster(kecnum) absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg using tablevisit`X', 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("With TV")
	
	areg `X' numchannelskec zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1 & ztv == 0, cluster(kecnum) absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg using tablevisit`X', 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("No TV")
	
	areg ln`X' numchannelskec zfemale zlhhexpcapnotv zrespedyears zelectricity zage `villagecontrols' if sample1 == 1 & ztv == 0, cluster(kecnum) absorb(kabnum)
	local depvar = e(depvar)
	qui summ `depvar' if e(sample) 
	outreg using tablevisit`X', 3aster coefastr se adds("Mean dep. var",r(mean)) append ctitle("No TV")

	
}
	
